@@ -72,7 +72,7 @@ typedef struct {
 			     sizeof (struct in6_addr))
 
 /* sockaddr port macros */
-#define SOUP_ADDRESS_PORT_IS_VALID(port) (port >= 0 && port <= 65535)
+#define SOUP_ADDRESS_PORT_IS_VALID(port) (((gint) port) >= 0 && port <= 65535)
 #define SOUP_ADDRESS_GET_PORT(priv) \
 	(priv->sockaddr->ss_family == AF_INET ? \
 		SOUP_SIN(priv)->sin_port : \
@@ -268,7 +268,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 				     "Name",
 				     "Hostname for this address",
 				     NULL,
-				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+				     G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_ADDRESS_FAMILY:
 	 *
@@ -282,7 +283,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 				   "Address family for this address",
 				   SOUP_TYPE_ADDRESS_FAMILY,
 				   SOUP_ADDRESS_FAMILY_INVALID,
-				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+				   G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_ADDRESS_PORT:
 	 *
@@ -295,7 +297,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 				  "Port",
 				  "Port for this address",
 				  -1, 65535, -1,
-				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+				  G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_ADDRESS_PROTOCOL:
 	 *
@@ -308,7 +311,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 				     "Protocol",
 				     "URI scheme for this address",
 				     NULL,
-				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+				     G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_ADDRESS_PHYSICAL:
 	 *
@@ -321,7 +325,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 				     "Physical address",
 				     "IP address for this address",
 				     NULL,
-				     G_PARAM_READABLE));
+				     G_PARAM_READABLE |
+				     G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_ADDRESS_SOCKADDR:
 	 *
@@ -333,7 +338,8 @@ soup_address_class_init (SoupAddressClass *address_class)
 		g_param_spec_pointer (SOUP_ADDRESS_SOCKADDR,
 				      "sockaddr",
 				      "struct sockaddr for this address",
-				      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
+				      G_PARAM_STATIC_STRINGS));
 }
 
 /**
@@ -1183,10 +1189,10 @@ got_addresses (SoupAddress *addr, guint status, gpointer user_data)
 	if (error)
 		g_task_return_error (task, g_error_copy (error));
 	else {
-		GSocketAddress *addr;
+		GSocketAddress *socket_addr;
 
-		addr = next_address (g_task_get_source_object (task));
-		g_task_return_pointer (task, addr, g_object_unref);
+		socket_addr = next_address (g_task_get_source_object (task));
+		g_task_return_pointer (task, socket_addr, g_object_unref);
 	}
 	g_object_unref (task);
 }
